package cn.iocoder.yudao.module.system.controller.admin.sms;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.system.convert.sms.SmsNodeConvert;
import cn.iocoder.yudao.module.system.service.sms.SmsNodeService;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.system.controller.admin.sms.vo.smsNode.*;
import cn.iocoder.yudao.module.system.dal.dataobject.sms.SmsNodeDO;

@Validated
@RestController
@Api(tags = "管理后台 - 短信节点")
@RequestMapping("/system/sms-node")
public class SmsNodeController {

    @Resource
    private SmsNodeService smsNodeService;

    @PostMapping("/create")
    @ApiOperation("创建短信节点")
    @PreAuthorize("@ss.hasPermission('system:sms-node:create')")
    public CommonResult<Long> createSmsNode(@Valid @RequestBody SmsNodeCreateReqVO createReqVO) {
        return success(smsNodeService.createSmsNode(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新短信节点")
    @PreAuthorize("@ss.hasPermission('system:sms-node:update')")
    public CommonResult<Boolean> updateSmsNode(@Valid @RequestBody SmsNodeUpdateReqVO updateReqVO) {
        smsNodeService.updateSmsNode(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除短信节点")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('system:sms-node:delete')")
    public CommonResult<Boolean> deleteSmsNode(@RequestParam("id") Long id) {
        smsNodeService.deleteSmsNode(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得短信节点")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('system:sms-node:query')")
    public CommonResult<SmsNodeBackVO> getSmsNode(@RequestParam("id") Long id) {
        SmsNodeDO smsNode = smsNodeService.getSmsNode(id);
        return success(SmsNodeConvert.INSTANCE.convert(smsNode));
    }

    @GetMapping("/list")
    @ApiOperation("获得短信节点列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('system:sms-node:query')")
    public CommonResult<List<SmsNodeBackVO>> getSmsNodeList(@RequestParam("ids") Collection<Long> ids) {
        List<SmsNodeDO> list = smsNodeService.getSmsNodeList(ids);
        return success(SmsNodeConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得短信节点分页")
    @PreAuthorize("@ss.hasPermission('system:sms-node:query')")
    public CommonResult<PageResult<SmsNodeBackVO>> getSmsNodePage(@Valid SmsNodeQueryVO query, PageVO page) {
        PageResult<SmsNodeDO> pageResult = smsNodeService.getSmsNodePage(query, page);
        return success(SmsNodeConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出短信节点 Excel")
    @PreAuthorize("@ss.hasPermission('system:sms-node:export')")
    @OperateLog(type = EXPORT)
    public void exportSmsNodeExcel(@Valid SmsNodeQueryVO query,
              HttpServletResponse response) throws IOException {
        List<SmsNodeDO> list = smsNodeService.getSmsNodeList(query);
        // 导出 Excel
        List<SmsNodeBackVO> datas = SmsNodeConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "短信节点.xls", "数据", SmsNodeBackVO.class, datas);
    }
}
