package cn.iocoder.yudao.module.system.service.sms;

import java.util.*;
import javax.validation.*;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;
import cn.iocoder.yudao.module.system.controller.admin.sms.vo.smsNode.*;
import cn.iocoder.yudao.module.system.dal.dataobject.sms.SmsNodeDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

/**
 * 短信节点 Service 接口
 *
 * @author jayden
 */
public interface SmsNodeService extends IService<SmsNodeDO> {

    /**
     * 创建短信节点
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createSmsNode(@Valid SmsNodeCreateReqVO createReqVO);

    /**
     * 更新短信节点
     *
     * @param updateReqVO 更新信息
     */
    void updateSmsNode(@Valid SmsNodeUpdateReqVO updateReqVO);

    /**
     * 删除短信节点
     *
     * @param id 编号
     */
    void deleteSmsNode(Long id);

    /**
     * 获得短信节点
     *
     * @param id 编号
     * @return 短信节点
     */
    SmsNodeDO getSmsNode(Long id);

    /**
     * 获得短信节点列表
     *
     * @param ids 编号
     * @return 短信节点列表
     */
    List<SmsNodeDO> getSmsNodeList(Collection<Long> ids);

    /**
     * 获得短信节点分页
     *
     * @param page  分页查询
     * @param query 查询
     * @return 短信节点分页
     */
    PageResult<SmsNodeDO> getSmsNodePage(SmsNodeQueryVO query, PageVO page);

    /**
     * 获得短信节点列表, 用于 Excel 导出
     *
     * @param query 查询
     * @return 短信节点列表
     */
    List<SmsNodeDO> getSmsNodeList(SmsNodeQueryVO query);

    /**
     * 构建缓存键
     * 根据SmsNodeDO对象的属性生成一个唯一的缓存键
     * 这是为了确保每个配置项在缓存中都有一个唯一的标识
     *
     * @param smsNodeDO SmsNodeDO 对象
     * @return 缓存键
     */
    String buildCacheKey(SmsNodeDO smsNodeDO);
}
